//User agents not recognized at all -> checking for Message-ID
//This here have to be anywhere in the identification line
//Font: UTF-8 (Ä Ö Ü)
dispMUA.arDispMUAAllocation["message-id"] =
{
  "@sitepoint.sparklist.com>" : [ "sparklist_com.png" , "http://www.sparklist.com/" , "sparklist" ] ,
  ".javamail.ngmail@webmail" : [ "arcor.png" , "http://www.arcor.de/" , "ARCOR" ] ,
  "@soquel.corp.apple.com>" : [ "apple_itunes.png" , "http://www.itunes.com/" , "Apple iTunes" ] ,
  "@secure.eve-online.com>" : [ "eve-online.png" , "http://www.eve-online.com/" , "EVE online" ] ,
  "<http://www.zataz.com/" : [ "zataz_com.png" , "http://www.zataz.com/" , "ZATAZ.com" ] ,
  ".sonyericssonmail.com>" : [ "sonyericsson.png" , "http://www.sonyericsson.com/" , "Sony Ericsson" ] ,
  "@www.norma-online.de>" : [ "norma-online_de.png" , "http://www.norma-online.de/" , "NORMA Online" ] ,
  "@yahoogrupos.com.br>" : [ "yahoo_groups_br.png" , "http://br.groups.yahoo.com/" , "Yahoo Brasil Grupos" ] ,
  "@www.pc-special.net>" : [ "pc-special_net.png" , "http://www.pc-special.net/" , "PC-Special.net" ] ,
  "@youropenvideo.com>" : [ "youropenmedia_com.png" , "http://www.youropenmedia.com/" , "Your Open Media" ] ,
  "@www.lastfm.com.tr>" : [ "last-fm.png" , "http://www.lastfm.com.tr/" , "Last.fm" ] ,
  "@www.lastfm.com.br>" : [ "last-fm.png" , "http://www.lastfm.com.br/" , "Last.fm" ] ,
  "@uci-kinowelt.info>" : [ "uci-kinowelt.png" , "http://www.uci-kinowelt.de/" , "UCI KINOWELT" ] ,
  "blackberry.rim.net" : [ "blackberry.png" , "http://www.blackberry.com/" , "Blackberry" ] ,
  "@www.spotlight.de>" : [ "spotlight.png" , "http://www.spotlight.de/" , "Spotlight.de - Die Net(te) Community" ] ,
  "@www.kiapress.com>" : [ "kia.png" , "http://www.kiapress.com/" , "KIA" ] ,
  "@amg.allmusic.com>" : [ "allmusic.png" , "http://www.allmusic.com/" , "THE ALLMUSIC BLOG" ] ,
  ".rightnowtech.com>" : [ "rightnowtech.png" , "http://www.rightnow.com/" , "RightNow Technologies" ] ,
  ".germany.jobpilot>" : [ "jobpilot_de.png" , "http://www.jobpilot.de/" , "jobpilot.de" ] ,
  ".evanzo-server.de>" : [ "evanzo.png" , "http://www.evanzo.de/" , "!EVANZO!" ] ,
  ".cortalconsors.de>" : [ "cortalconsors.png" , "http://www.cortalconsors.de/" , "Cortal Consors" ] ,
  ".browsershots.org>" : [ "browsershots_org.png" , "http://browsershots.org/" , "Browsershots" ] ,
  ".arcor-online.net>" : [ "arcor.png" , "http://www.arcor.de/" , "ARCOR" ] ,
  "@yahoogroups.com>" : [ "yahoo_groups.png" , "http://groups.yahoo.com/" , "Yahoo Groups" ] ,
  "@yahoogroupes.fr>" : [ "yahoo_groups_fr.png" , "http://fr.groups.yahoo.com/" , "Yahoo France Groupes" ] ,
  "@relay.skynet.be>" : [ "skynet_be.png" , "http://www.skynet.be/" , "skynet Belgacom" ] ,
  "@merter-musek.lu>" : [ "musek_lu.png" , "http://www.merter-musek.lu/" , "Merter Musek" ] ,
  ".thestandard.com>" : [ "thestandard_com.png" , "http://www.thestandard.com/" , "The Industry Standard" ] ,
  ".mailinblack.com>" : [ "mailinblack.png" , "http://mailinblack.com/" , "MAILinBlack" ] ,
  ".kundenserver.de>" : [ "1und1.png" , "http://www.1und1.de/" , "1&1" ] ,
  ".auctionweb.info>" : [ "auktionmaster.png" , "http://www.auktionmaster.de/" , "AuctionWeb" ] ,
  "@poczta.jaaz.pl>" : [ "jaaz_pl.png" , "http://www.jaaz.pl/" , "jaaz.pl" ] ,
  "@iwantsandy.com>" : [ "sandy.png" , "http://www.iwantsandy.com/" , "Sandy" ] ,
  "@googlemail.com>" : [ "google_googlemail.png" , "http://www.googlemail.com/" , "Google Mail" ] ,
  ".youthhostel.ch>" : [ "youthhostel_ch.png" , "http://www.youthhostel.ch/" , "Swiss Youthhostels" ] ,
  ".trendmicro.com>" : [ "trendmicro.png" , "http://www.trendmicro.com/" , "TrendMicro" ] ,
  ".telenet-ops.be>" : [ "telenet_be.png" , "http://telenet.be/" , "Telenet" ] ,
  ".corp.yahoo.com>" : [ "yahoo-inc.png" , "http://info.yahoo.com/center/us/yahoo/" , "Yahoo! Inc" ] ,
  ".auckland.ac.nz>" : [ "uni_auckland.png" , "http://www.auckland.ac.nz/" , "The University of Auckland" ] ,
  ".altervista.org>" : [ "altervista.png" , "http://www.altervista.org/" , "alterVISTA" ] ,
  "@yahoo-inc.com>" : [ "yahoo-inc.png" , "http://info.yahoo.com/center/us/yahoo/" , "Yahoo! Inc" ] ,
  "@www.lastfm.se>" : [ "last-fm.png" , "http://www.lastfm.se/" , "Last.fm" ] ,
  "@www.lastfm.ru>" : [ "last-fm.png" , "http://www.lastfm.ru/" , "Last.fm" ] ,
  "@www.lastfm.pl>" : [ "last-fm.png" , "http://www.lastfm.pl/" , "Last.fm" ] ,
  "@www.lastfm.jp>" : [ "last-fm.png" , "http://www.lastfm.jp/" , "Last.fm" ] ,
  "@www.lastfm.it>" : [ "last-fm.png" , "http://www.lastfm.it/" , "Last.fm" ] ,
  "@www.lastfm.fr>" : [ "last-fm.png" , "http://www.lastfm.fr/" , "Last.fm" ] ,
  "@www.lastfm.es>" : [ "last-fm.png" , "http://www.lastfm.es/" , "Last.fm" ] ,
  "@www.lastfm.de>" : [ "last-fm.png" , "http://www.lastfm.de/" , "Last.fm" ] ,
  "@trashmail.net>" : [ "trashmail.png" , "http://www.trashmail.net/" , "TrashMail" ] ,
  "@smarttools.de>" : [ "smarttools.png" , "http://www.smarttools.de/" , "SmartTools" ] ,
  "@genealogy.net>" : [ "genealogy_net.png" , "http://www.genealogy.net/" , "Verein f. Computergenealogie" ] ,
  "@de.domeus.com>" : [ "ecircle.png" , "http://www.domeus.de/" , "domeus" ] ,
  ".yousendit.com>" : [ "yousendit.png" , "http://www.yousendit.com/" , "YouSendIt" ] ,
  ".microsoft.com>" : [ "microsoft.png" , "http://www.microsoft.com/" , "Microsoft" ] ,
  ".hosteurope.de>" : [ "hosteurope_de.png" , "http://www.hosteurope.de/" , "Host Europe" ] ,
  "@vdo-out-f.ax>" : [ "continental.png" , "http://www.vdo.de/" , "Continental" ] ,
  "@mail.kios.sk>" : [ "kerio_ms.png" , "http://www.kerio.com/kms_home.html" , "Kerio MailServer" ] ,
  "@kundenserver>" : [ "1und1.png" , "http://www.1und1.de/" , "1&1" ] ,
  "@docomo.ne.jp>" : [ "nttdocomo.png" , "http://www.nttdocomo.co.jp/" , "NTT docomo" ] ,
  ".truition.com>" : [ "truition.png" , "http://www.truition.com/" , "Truition" ] ,
  ".spickmich.de>" : [ "spickmich.png" , "http://www.spickmich.de/" , "spickmich.de" ] ,
  ".points24.com>" : [ "points24_com.png" , "http://www.points24.com/" , "points24.com" ] ,
  ".moikrewni.pl>" : [ "moikrewni_pl.png" , "http://www.moikrewni.pl/" , "moikrewni.pl" ] ,
  ".mail2web.com>" : [ "mail2web_com.png" , "http://www.mail2web.com/" , "mail2web.com" ] ,
  ".helukabel.de>" : [ "helukabel.png" , "http://helukabel.de/" , "HELUKABEL" ] ,
  ".comdirect.de>" : [ "comdirect_de.png" , "http://www.comdirect.de/" , "comdirect bank AG" ] ,
  "@www.last.fm>" : [ "last-fm.png" , "http://www.last.fm/" , "Last.fm" ] ,
  "@youtube.com>" : [ "youtube.png" , "http://www.youtube.com/" , "YouTube" ] ,
  "@t-online.de>" : [ "t-online.png" , "http://www.t-online.de/" , "T-Online" ] ,
  "@smtp.hm.com>" : [ "hm_com.png" , "http://www.hm.com/" , "H&M" ] ,
  "@homes.co.jp>" : [ "homes_co_jp.png" , "http://www.homes.co.jp/" , "HOME'S" ] ,
  "@akzente.net>" : [ "akzente_net.png" , "http://www.akzente.net/" , "Akzente Salzburg" ] ,
  ".yahoo.co.jp>" : [ "yahoo.png" , "http://mail.yahoo.co.jp/" , "Yahoo! Mail" ] ,
  ".versatel.de>" : [ "versatel.png" , "http://www.versatel.de/" , "versatel" ] ,
  ".studivz.net>" : [ "studivz.png" , "http://www.studivz.net/" , "studiVZ" ] ,
  ".opendns.com>" : [ "opendns.png" , "http://www.opendns.com/" , "openDNS" ] ,
  ".mozilla.org>" : [ "mozilla.png" , "http://www.mozilla.org/" , "Mozilla" ] ,
  ".klicktel.de>" : [ "klicktel_de.png" , "http://www.klicktel.de/" , "klickTel.de" ] ,
  ".gmx-gmbh.de>" : [ "gmx.png" , "http://www.gmx.de/" , "GMX" ] ,
  ".freemail.hu>" : [ "freemail_hu.png" , "http://www.freemail.hu/" , "freemail.hu" ] ,
  ".emarsys.net>" : [ "emarsys.png" , "http://www.emarsys.de/" , "Emarsys" ] ,
  ".dab-bank.de>" : [ "dab-bank_de.png" , "http://www.dab-bank.de/" , "DAB bank" ] ,
  "@vilitas.de>" : [ "vilitas.png" , "http://www.vilitas.de/" , "Vilitas Merchandise" ] ,
  "@paypal.com>" : [ "paypal.png" , "http://www.paypal.com/" , "PayPal" ] ,
  "@interia.pl>" : [ "interia_pl.png" , "http://www.interia.pl/" , "interia.pl" ] ,
  "@immonet.de>" : [ "immonet_de.png" , "http://www.immonet.de/" , "immonet.de" ] ,
  "@ikoula.com>" : [ "ikoula.png" , "http://www.ikoula.com/" , "ikoula" ] ,
  "@google.com>" : [ "google.png" , "http://www.google.com/" , "Google" ] ,
  "@cn.last.fm>" : [ "last-fm.png" , "http://cn.last.fm/" , "Last.fm" ] ,
  ".udmedia.de>" : [ "udmedia_de.png" , "http://www.udmedia.de/" , "UD Media" ] ,
  ".tiscali.de>" : [ "tiscali_de.png" , "http://www.tiscali.de/" , "Tiscali Deutschland" ] ,
  ".tipp24.net>" : [ "lotto.png" , "http://www.tipp24.com/" , "Tipp24" ] ,
  ".oracle.com>" : [ "oracle.png" , "http://www.oracle.com/" , "ORACLE" ] ,
  ".nabble.com>" : [ "nabble.png" , "http://www.nabble.com/" , "Nabble" ] ,
  ".google.com>" : [ "google.png" , "http://www.google.com/" , "Google" ] ,
  ".bluewin.ch>" : [ "bluewin_ch.png" , "http://www.bluewin.ch/" , "bluewin.ch" ] ,
  ".amazon.com>" : [ "amazon.png" , "http://www.amazon.com/" , "Amazon" ] ,
  ".allianz.de>" : [ "allianz_de.png" , "http://www.allianz.de/" , "Allianz" ] ,
  "@walla.com>" : [ "walla.png" , "http://www.walla.co.il/" , "Walla!" ] ,
  "@strato.de>" : [ "strato.png" , "http://www.strato.de/" , "STRATO AG" ] ,
  "@seznam.cz>" : [ "seznam_cz.png" , "http://www.seznam.cz/" , "Seznam" ] ,
  "@operon.pl>" : [ "operon_pl.png" , "http://www.operon.pl/" , "operon.pl" ] ,
  "@libero.it>" : [ "libero_it.png" , "http://liberomail.libero.it/" , "libero.it" ] ,
  "@gmail.com>" : [ "google_gmail.png" , "http://www.gmail.com/" , "GMail" ] ,
  "@fritz.box>" : [ "fritzbox.png" , "http://www.avm.de/" , "FRITZ!Box" ] ,
  "@cvsserver>" : [ "cvs.png" , "" , "CVS" ] ,
  "@conrad.de>" : [ "conrad.png" , "http://www.conrad.de/" , "Conrad Electronic" ] ,
  ".yahoo.com>" : [ "yahoo.png" , "http://www.yahoo.com/" , "Yahoo" ] ,
  ".strato.de>" : [ "strato.png" , "http://www.strato.de/" , "STRATO AG" ] ,
  ".paypal.de>" : [ "paypal.png" , "http://www.paypal.de/" , "PayPal" ] ,
  ".orange.sk>" : [ "orange.png" , "http://www.orangeportal.sk/" , "Orange Slovensko" ] ,
  ".oleco.com>" : [ "oleco_com.png" , "http://www.oleco.com/" , "Oleco" ] ,
  ".nestle.de>" : [ "nestle.png" , "http://www.nestle.de/" , "Nestle" ] ,
  ".libero.it>" : [ "libero_it.png" , "http://liberomail.libero.it/" , "libero.it" ] ,
  ".gmail.com>" : [ "google_gmail.png" , "http://www.gmail.com/" , "GMail" ] ,
  ".avira.com>" : [ "avira.png" , "http://www.avira.com/" , "Avira" ] ,
  ".apple.com>" : [ "apple.png" , "http://www.apple.com/" , "Apple" ] ,
  ".ampega.de>" : [ "ampega.png" , "http://www.ampegagerling.de/" , "ampegaGerling.de" ] ,
  ".1and1.com>" : [ "1und1.png" , "http://www.1and1.com/" , "1&1" ] ,
  "@xmr3.com>" : [ "xmr3_com.png" , "http://www.xmr3.com/" , "messageReach" ] ,
  "@funke.de>" : [ "funke_de.png" , "http://www.funke.de/" , "FUNKE GmbH" ] ,
  "@be3a.com>" : [ "be3a.png" , "http://www.be3a.com/" , "B!3A" ] ,
  "@agfeo.de>" : [ "agfeo.png" , "http://www.agfeo.de/" , "AGFEO" ] ,
  ".xing.com>" : [ "xing.png" , "http://www.xing.com/" , "XING" ] ,
  ".xbox.com>" : [ "xbox.png" , "http://www.xbox.com/" , "XBOX" ] ,
  ".usps.gov>" : [ "usps.png" , "http://www.usps.com/" ] ,
  ".ucsf.edu>" : [ "ucsf.png" , "http://www.ucsf.edu/" , "University of California, San Francisco" ] ,
  ".nokia.at>" : [ "nokia.png" , "http://www.nokia.at/" , "Nokia (Austria)" ] ,
  ".lidl.net>" : [ "lidl.png" , "http://www.lidl.net/" , "Lidl Online" ] ,
  ".kwick.de>" : [ "kwick.png" , "http://www.kwick.de/" , "KWICK! Community" ] ,
  ".kilu.net>" : [ "kilu_de.png" , "http://www.kilu.de/" , "Kilu" ] ,
  ".ikea.com>" : [ "ikea.png" , "http://www.ikea.com/" , "IKEA" ] ,
  ".iacd.net>" : [ "iacd_net.png" , "http://www.iacd.net/" , "Internet Access Center Düsseldorf" ] ,
  ".heise.de>" : [ "heise.png" , "http://www.heise.de/" , "Heise Online" ] ,
  ".golem.de>" : [ "golem.png" , "http://www.golem.de/" , "Golem.de" ] ,
  ".fagms.de>" : [ "mailsolution_de.png" , "http://www.mailsolution.de/" , "United Mailsolutions" ] ,
  ".ebay.com>" : [ "ebay.png" , "http://www.ebay.com/" , "ebay" ] ,
  ".dell.com>" : [ "dell.png" , "http://www.dell.com/" , "Dell" ] ,
  ".aakus.de>" : [ "aakus_de.png" , "http://www.aakus.com/" , "Äakus AG" ] ,
  ".1und1.de>" : [ "1und1.png" , "http://www.1und1.de/" , "1&1" ] ,
  "<mdaemon-" : [ "mdaemon.png" , "http://www.interbel.es/productos/mdaemon/" , "MDaemon" ] ,
  "@phx.gbl>" : [ "msn.png" , "http://www.msn.com/" , "MSN" ] ,
  "@lidl.nl>" : [ "lidl.png" , "http://www.lidl.nl/" , "Lidl.nl" ] ,
  "@lidl.fr>" : [ "lidl.png" , "http://www.lidl.fr/" , "Lidl.fr" ] ,
  "@lidl.de>" : [ "lidl.png" , "http://www.lidl.de/" , "Lidl.de" ] ,
  "@lidl.be>" : [ "lidl.png" , "http://www.lidl.be/" , "Lidl.be" ] ,
  "@gmx.net>" : [ "gmx.png" , "http://www.gmx.net/" , "GMX" ] ,
  ".ups.com>" : [ "ups.png" , "http://www.ups.com/" , "United Parcel Service" ] ,
  ".otto.de>" : [ "otto_de.png" , "http://www.otto.de/" , "Otto Versand" ] ,
  ".mail.ru>" : [ "mail_ru.png" , "http://www.mail.ru/" , "@mail.ru" ] ,
  ".mail.ee>" : [ "mail_ee.png" , "http://www.mail.ee/" , "Mail.ee" ] ,
  ".gmx.net>" : [ "gmx.png" , "http://www.gmx.net/" , "GMX" ] ,
  ".ibm.com>" : [ "ibm.png" , "http://www.ibm.com/" , "IBM" ] ,
  ".chip.de>" : [ "chip_de.png" , "http://www.chip.de/" , "CHIP Online" ] ,
  ".cevi.be>" : [ "cevi_be.png" , "http://www.cevi.be/" , "Cevi NV" ] ,
  ".buch.de>" : [ "buch_de.png" , "http://www.buch.de/" , "buch.de" ] ,
  "@web.de>" : [ "web_de.png" , "http://www.web.de/" , "Web.de" ] ,
  "@gmx.de>" : [ "gmx.png" , "http://www.gmx.de/" , "GMX" ] ,
  "@gmx.ch>" : [ "gmx.png" , "http://www.gmx.ch/" , "GMX" ] ,
  "@avm.de>" : [ "avm_de.png" , "http://www.avm.de/" , "AVM" ] ,
  ".web.de>" : [ "web_de.png" , "http://www.web.de/" , "Web.de" ] ,
  ".sko.de>" : [ "crednet.png" , "http://www.sko.de/" , "crednet" ] ,
  ".sbs.de>" : [ "siemens.png" , "http://www.sbs.de/" , "Siemens" ] ,
  ".one.lt>" : [ "one.png" , "http://www.one.lt/" , "ONE webmail" ] ,
  ".one.lv>" : [ "one.png" , "http://www.one.lv/" , "ONE webmail" ] ,
  ".kei.pl>" : [ "kei_pl.png" , "http://www.kei.pl/" , "Kei.pl" ] ,
  "<paypal." : [ "paypal.png" , "http://www.paypal.com/" , "PayPal" ] ,
  "@o2.pl>" : [ "o2_pl.png" , "http://www.o2.pl/" , "o2.pl" ] ,
  ".tmail>" : [ "tmail.png" , "http://tmail.rubyforge.org/" , "TMail" ] ,
  ".qmail@" : [ "qmail.png" , "http://www.qmail.org/" ] ,
  ".ezmlm@" : [ "ezmlm.png" , "http://cr.yp.to/ezmlm.html" , "ezmlm" ] ,
  ".ba.de>" : [ "ba.png" , "http://www.arbeitsagentur.de/" ] ,
  "<lyris-" : [ "lyris.png" , "http://www.lyris.com/" , "Lyris" ] ,
  "<pine." : [ "pine.png" , "http://www.washington.edu/pine/" , "Pine" ] ,
  "<rt-" : [ "bestpractical_com.png" , "http://bestpractical.com/rt/" , "RT: Request Tracker" ] ,
// Fallback
  ".javamail." : [ "javamail.png" , "http://java.sun.com/products/javamail/" , "JavaMail" ] ,
}
